summaryrefslogtreecommitdiff
path: root/src/cpu/testers/traffic_gen/traffic_gen.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/cpu/testers/traffic_gen/traffic_gen.hh')
-rw-r--r--src/cpu/testers/traffic_gen/traffic_gen.hh14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/cpu/testers/traffic_gen/traffic_gen.hh b/src/cpu/testers/traffic_gen/traffic_gen.hh
index a2fcd3bc0..c013109b7 100644
--- a/src/cpu/testers/traffic_gen/traffic_gen.hh
+++ b/src/cpu/testers/traffic_gen/traffic_gen.hh
@@ -74,25 +74,22 @@ class TrafficGen : public MemObject
void enterState(uint32_t newState);
/**
* Get the tick of the next event, either an execution or a
* transition.
*
* @return tick of the next update event
*/
Tick nextEventTick()
{
- return std::min(states[currState]->nextExecuteTick(),
+ return std::min(states[currState]->nextPacketTick(),
nextTransitionTick);
}
/**
* Parse the config file and build the state map and
* transition matrix.
- *
- * @param file_name Config file name to parse
- * @param master_id MasterID to use for generated requests
*/
- void parseConfig(const std::string& file_name, MasterID master_id);
+ void parseConfig();
/**
* Schedules event for next update and executes an update on the
@@ -119,6 +116,11 @@ class TrafficGen : public MemObject
*/
MasterID masterID;
+ /**
+ * The config file to parse.
+ */
+ const std::string configFile;
+
/** Time of next transition */
Tick nextTransitionTick;
@@ -74,25 +74,22 @@ class TrafficGen : public MemObject
void enterState(uint32_t newState);
/**
- * Get the tick of the next event, either an execution or a
+ * Get the tick of the next event, either a new packet or a
* transition.
*